-- Classic Raid Info v1.13-r6
if WOW_PROJECT_ID ~= WOW_PROJECT_CLASSIC then
	return
end

local headerHeight = 12

local US = {
	["Anathema"] = true,
	["Arcanite Reaper"] = true,
	["Arugal"] = true,
	["Ashkandi"] = true,
	["Atiesh"] = true,
	["Azuresong"] = true,
	["Benediction"] = true,
	["Bigglesworth"] = true,
	["Blaumeux"] = true,
	["Bloodsail Buccaneers"] = true,
	["Deviate Delight"] = true,
	["Earthfury"] = true,
	["Faerlina"] = true,
	["Fairbanks"] = true,
	["Felstriker"] = true,
	["Grobbulus"] = true,
	["Heartseeker"] = true,
	["Herod"] = true,
	["Incendius"] = true,
	["Kirtonos"] = true,
	["Kromcrush"] = true,
	["Kurinaxx"] = true,
	["Kurinnaxx"] = true,
	["Loatheb"] = true,
	["Mankrik"] = true,
	["Myzrael"] = true,
	["Netherwind"] = true,
	["Old Blanchy"] = true,
	["Pagle"] = true,
	["Rattlegore"] = true,
	["Remulos"] = true,
	["Skeram"] = true,
	["Smolderweb"] = true,
	["Stalagg"] = true,
	["Sulfuras"] = true,
	["Sul'thraze"] = true,
	["Thalnos"] = true,
	["Thunderfury"] = true,
	["Westfall"] = true,
	["Whitemane"] = true,
	["Windseeker"] = true,
	["Yojamba"] = true,
}

local DisplaySequence = { 409, 469, 531, 533, 249, 309, 509 }
local RaidInfo = {
	[409] = {
		name = "MC",
		nameConfig = "Molten Core",		
		size = 40,
		bosses = 10,
		initstatus = false,
		reset = 1,
	},
	[249] = {
		name = "Onyxia",
		nameConfig = "Onyxia's Lair",				
		size = 40,
		bosses = 1,
		initstatus = true,
		reset = 2,
	},
	[469] = {
		name = "BWL",
		nameConfig = "Blackwing Lair",				
		size = 40,
		bosses = 8,
		initstatus = true,
		reset = 1,
	},
	[309] = {
		name = "ZG",
		nameConfig = "Zul'Gurub",				
		size = 20,
		bosses = 11,
		initstatus = true,
		reset = 3,
	},
	[531] = {
		name = "AQ40",
		nameConfig = "Temple of Ahn'Qiraj",				
		size = 40,
		bosses = 9,
		initstatus = true,
		reset = 1,
	},
	[509] = {
		name = "AQ20",
		nameConfig = "Ruins of Ahn'Qiraj",				
		size = 20,
		bosses = 6,
		initstatus = false,
		reset = 3,
	},
	[533] = {
		name = "Naxx",
		nameConfig = "Naxxramas",				
		size = 40,
		bosses = 15,
		initstatus = true,
		reset = 1,
	},
}

local RaidResets = {
	[1] = {
		us = 1592323200,
		other = 1592377200,
		days = 604800, -- 7 [86400 * 7]
	},
	[2] = {
		us = 1592496000,
		other = 1592377200,
		days = 432000, -- 5 [86400 * 5]
	},
	[3] = {
		us = 1592496000,
		other = 1592722800,
		days = 259200 -- 3 [86400 * 3]
	},
}

local InstanceNames = {}
for k,_ in pairs(RaidInfo) do
	InstanceNames[GetRealZoneText(k)] = k
end

local function GetInstanceBossInfo(index)
	local name, _, reset, _, locked, _, _, _, _, _, _, encounterProgress = GetSavedInstanceInfo(index)
	locked = locked and 2 or 1
	instanceid = InstanceNames[name]
	return name, instanceid, reset, locked, encounterProgress
end

local function GetInstanceTimeInfo(index)
	local name, instanceid, reset, locked, encounterProgress
	instanceid = DisplaySequence[index]
	local raidreset = RaidResets[RaidInfo[instanceid].reset]
	local nowTime = GetServerTime()
	local startTime = US[GetRealmName()] and raidreset.us or raidreset.other
	local nextReset = raidreset.days
	local nextResetOffset = math.ceil((nowTime - startTime) / nextReset)
	name = GetRealZoneText(instanceid)
	reset = startTime + (nextReset * nextResetOffset) - nowTime
	locked = 0	
	encounterProgress = 0
	return name, instanceid, reset, locked, encounterProgress
end

StatusColors = {
	[0] = "|cff00f26d", -- not saved
	[1] = "|cff00f26d", --Progressing
	[2] = "|cffC41E3A", --Locked
}
local function UpdateStatus(status, lockststus, reset, progress)
	status.FontString:SetText(status.name .. ": " .. StatusColors[lockststus] .. " [".. progress .. "/" .. status.bosses .. "] Resets in: " .. reset .. "|r")
end

local InstanceUpdates = {}
local function UpdateAllInstances()
	local numInstances = GetNumSavedInstances()
	table.wipe(InstanceUpdates)
	for i=1, numInstances do
		local name, instanceid, reset, locked, encounterProgress = GetInstanceBossInfo(i)
		local status = RaidInfo[instanceid]
		status.locked = locked
		status.encounterProgress = encounterProgress
		InstanceUpdates[instanceid] = true
		UpdateStatus(status, locked, SecondsToTime(reset), encounterProgress)
	end
	for i=1, #DisplaySequence do
		if not InstanceUpdates[DisplaySequence[i]] then
			local status = RaidInfo[DisplaySequence[i]]
			status.locked = 0
			status.encounterProgress = 0
			local name, instanceid, reset, locked, encounterProgress = GetInstanceTimeInfo(i)
			UpdateStatus(status, status.locked, SecondsToTime(reset), status.encounterProgress)
		end
	end
end

--------------------
-- Classic Raid Info
--------------------
local function initSinLockoutDB()
	if not SinLockoutDB then
		SinLockoutDB = {
			SinLockVar = false,
			SinHideVar = true,
			RaidFontSize = 12,
			Raids = {},
		}   
		-- converted from saving data using abbreviated instance names (MC, NAX etc.) to save using the instance id 
		for k, v in pairs(RaidInfo) do
			SinLockoutDB.Raids[k] = v.initstatus
		end
		if not SinLockoutDB.RaidFontSize then
			SinLockoutDB.RaidFontSize  = 12
		end 
	end
	
	if not SinLockoutDB.minimap then
        SinLockoutDB.minimap = {
            hide = true,
        }	
	end		
	
	local criDB = LibStub("LibDataBroker-1.1"):NewDataObject("ClassicRaidInfo", {
		type = "data source",
		text = "Classic Raid Info",
		icon = "Interface\\Icons\\Inv_trinket_naxxramas02",
		OnTooltipShow = function(tooltip)
			tooltip:SetText("|cff00f26dClassic Raid Info|r")
			tooltip:AddLine("|cff00f26dLeft click :|r Open/Close the settings", 1, 1, 1)
			tooltip:AddLine("|cff00f26dRight click :|r Enable/Disable the raid info frame", 1, 1, 1)
			tooltip:Show()
		end,
		OnClick = function(self, button, down) 
			if button == "LeftButton" then
				if LockoutConfigFrame:IsShown() then
					HideUIPanel(LockoutConfigFrame) 
				else
					ShowUIPanel(LockoutConfigFrame) 
				end
			elseif button == "RightButton" then
				if SinLockoutFrame:IsShown() then
				SinLockoutDB.SinHideVar = false
				criToggle:SetChecked(SinLockoutDB.SinHideVar)
				criToggle.hideCRI:SetText("[|cffC41E3ADisabled|r]")
				SinLockoutFrame:Hide()
				else
				SinLockoutDB.SinHideVar = true
				criToggle:SetChecked(SinLockoutDB.SinHideVar)
				criToggle.hideCRI:SetText(SinLockoutDB.SinHideVar and "[|cff00f26dEnabled|r]")
				SinLockoutFrame:Show()
				end
				end
		end,
	})
	criLogo = LibStub("LibDBIcon-1.0")
	criLogo:Register("ClassicRaidInfo", criDB, SinLockoutDB.minimap) 	
	
end
 
local function CreateConfig(raidframe)
local BdTemplate = BackdropTemplateMixin and "BackdropTemplate" or ""
local LockoutConfig = CreateFrame("frame","LockoutConfigFrame", UIParent, 'ShadowOverlayTemplate'..BdTemplate)
LockoutConfig.RaidFrame = raidframe
LockoutConfig:RegisterEvent("ADDON_LOADED")
LockoutConfig:RegisterEvent("PLAYER_LOGOUT")
LockoutConfig:SetBackdrop({
		bgFile="Interface/DialogFrame/UI-DialogBox-Background-Dark",
		--edgeFile="Interface/DialogFrame/UI-DialogBox-Background-Dark",
		tile=1, tileSize=0, edgeSize=5,
	 })
LockoutConfig:SetBackdropColor(1,1,1,1)
LockoutConfig:SetWidth(510)
LockoutConfig:SetHeight(305)
LockoutConfig:Hide()
LockoutConfig:SetPoint("CENTER",UIParent)
LockoutConfig:EnableMouse(true)
LockoutConfig:SetMovable(true)
LockoutConfig:RegisterForDrag("LeftButton")
LockoutConfig:SetScript("OnDragStart", function(self) self:StartMoving() end)
LockoutConfig:SetScript("OnDragStart", function(self) self:StartMoving() end)
LockoutConfig:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
LockoutConfig:SetFrameStrata("FULLSCREEN_DIALOG")
tinsert(UISpecialFrames, "LockoutConfigFrame")

local slider = CreateFrame("Slider", "SinLockoutSlider", LockoutConfig, 'OptionsSliderTemplate')
_G[slider:GetName() .. 'Low']:SetText('8'); 
_G[slider:GetName() .. 'High']:SetText('30');   
_G[slider:GetName() .. 'Text']:SetText('Text Size');
slider:SetMinMaxValues(8, 30)
slider:SetValueStep(1)
slider.slideTitle = slider:CreateFontString(nil, "OVERLAY");
slider.slideTitle:SetFontObject("GameFontHighlightSmall");
slider:SetScript("OnValueChanged", function (self)
	local value = math.floor(self:GetValue())
	SinLockoutDB.RaidFontSize = value
	SinLockoutFrame:RestiseStats()
	slider.slideTitle:SetText("Current: " .. SinLockoutDB.RaidFontSize )
end)
slider:SetValue(SinLockoutDB.RaidFontSize)
 
LockoutConfig.SinTitle = LockoutConfig:CreateFontString(nil, "OVERLAY");
LockoutConfig.SinTitle:SetFontObject("GameFontHighlightLarge");
LockoutConfig.SinTitle:SetPoint("TOP", LockoutConfig, "TOP", 0, -7);
LockoutConfig.SinTitle:SetText("|cff00f26dClassic Raid Info|r");
 
LockoutConfig.SigSection = LockoutConfig:CreateFontString(nil, "OVERLAY");
LockoutConfig.SigSection:SetFontObject("GameFontHighlightSmall");
LockoutConfig.SigSection:SetPoint("BOTTOMRIGHT", -2, 3);
LockoutConfig.SigSection:SetText("|cff00f26dby Sinba-Pagle  v1.13-r6");
 
LockoutConfig.SinXButton = CreateFrame('Button', 'SinXButton', LockoutConfig, "UIPanelCloseButton")
LockoutConfig.SinXButton:SetPoint('TOPRIGHT', 0,0)
LockoutConfig.SinXButton:SetSize(25, 25)
LockoutConfig.SinXButton:SetScript('OnClick', function(self)
	self:GetParent():Hide()
end)
 
LockoutConfig.SinReset = CreateFrame('Button', 'SinReset', LockoutConfig, "UIPanelButtonTemplate")
LockoutConfig.SinReset:SetSize(135, 20)
LockoutConfig.SinReset:SetText("Reset Position")
LockoutConfig.SinReset:SetScript('OnClick', function(self)
	StaticPopup_Show("SINLOCKOUT_HUD_RESET")
end)
 
local ChkBoxVar = CreateFrame("CheckButton", "$parentSinLockFrame", LockoutConfig, "ChatConfigCheckButtonTemplate")
ChkBoxVar.LockFr = ChkBoxVar:CreateFontString(nil, "OVERLAY");
ChkBoxVar.LockFr:SetFontObject("GameFontHighlight");
ChkBoxVar.LockFr:SetPoint("LEFT", ChkBoxVar, "RIGHT", 5, 0);
ChkBoxVar.tooltip = "Lock/Unlock the frame"
ChkBoxVar:SetScript('OnClick', function(self)
	local SinLockout = SinLockoutFrame
	SinLockoutDB.SinLockVar = self:GetChecked()
	ChkBoxVar.LockFr:SetText(SinLockoutDB.SinLockVar and "[|cffd4080cLocked|r]" or "[|cff00f26dUnlocked|r]")        
	local parent = self:GetParent()
	if SinLockoutDB.SinLockVar == true then
		SinLockout:SetUserPlaced(true)
		SinLockout:SetMovable(true);
		SinLockout:EnableMouse(false);       
		SinLockout:SetUserPlaced(true)       
		SinLockout:SetBackdropColor(1,1,1,0)
		SinLockout.DragText:Hide()
	elseif SinLockoutDB.SinHideVar == false and not SinLockoutDB.SinLockVar then
		SinLockout:SetMovable(true);
		SinLockout:EnableMouse(true);
		SinLockout:SetUserPlaced(true);
		SinLockout:SetBackdropColor(1,1,1,0)
		SinLockout.DragText:Hide()
	elseif not SinLockoutDB.SinLockVar then
		SinLockout:SetMovable(true);
		SinLockout:EnableMouse(true);
		SinLockout:SetUserPlaced(true);      
		SinLockout:SetBackdropColor(1,1,1,1)
		SinLockout.DragText:Show()
	end
end)
ChkBoxVar:SetChecked(SinLockoutDB.SinLockVar)
ChkBoxVar:GetScript('OnClick')(ChkBoxVar)

criToggle = CreateFrame("CheckButton", "$parentSinRaidHide", LockoutConfig, "ChatConfigCheckButtonTemplate")
criToggle.hideCRI = criToggle:CreateFontString(nil, "OVERLAY");
criToggle.hideCRI:SetFontObject("GameFontHighlight");
criToggle.hideCRI:SetPoint("LEFT", criToggle, "RIGHT", 5, 0);
criToggle.tooltip = "Enable/Disable the Raid Info"
criToggle:SetScript('OnClick', function(self)
	local Parent = self:GetParent()
	local SinLockout = SinLockoutFrame
	SinLockoutDB.SinHideVar = self:GetChecked()
	criToggle.hideCRI:SetText(SinLockoutDB.SinHideVar and "[|cff00f26dEnabled|r]" or "[|cffC41E3ADisabled|r]")
	if SinLockoutDB.SinHideVar then
		SinLockout:Show()
	elseif not SinLockoutDB.SinHideVar and not SinLockoutDB.SinLockVar then
		SinLockout:Hide()
	else
		SinLockout:Hide()
	end
end)
criToggle:SetChecked(SinLockoutDB.SinHideVar)
criToggle:GetScript('OnClick')(criToggle)

local minimapOption = CreateFrame("CheckButton", "$parentminimapOption", RaidConsumeConfig, "ChatConfigCheckButtonTemplate")
minimapOption.crimmToggle = minimapOption:CreateFontString(nil, "OVERLAY");
minimapOption.crimmToggle:SetFontObject("GameFontHighlight");
minimapOption.crimmToggle:SetPoint("LEFT", minimapOption, "RIGHT", 5, 0);
minimapOption.tooltip = "Toggle the minimap icon"
minimapOption:SetScript('OnClick', function(self)
        SinLockoutDB.minimap.hide = self:GetChecked()
        minimapOption.crimmToggle:SetText(not SinLockoutDB.minimap.hide and "Minimap Icon: |cffC41E3ADisabled|r" or "Minimap Icon: |cff00f26dEnabled|r")        
	if SinLockoutDB.minimap.hide then      
		criLogo:Show("ClassicRaidInfo") 
	else
		criLogo:Hide("ClassicRaidInfo") 
	end		
end)		
minimapOption:SetChecked(SinLockoutDB.minimap.hide)
minimapOption:GetScript('OnClick')(minimapOption) 	

-----------------------------------------------------
-- Factory functions for creating check boxes
-----------------------------------------------------
 
    local function TabOnClick(self) 
        PlaySound(SOUNDKIT.IG_CHARACTER_INFO_TAB)
        local ID = self:GetID()
        self:SetAlpha(1)
        self.widgets:Show()
        local parent = self:GetParent()
        for i=1, #parent.Tabs do
            if i ~= ID then
                parent.Tabs[i]:SetAlpha(0.5)
                parent.Tabs[i].widgets:Hide()
            end
        end
    end
     
    local function CreateTab(id, parent, text)
            local f = CreateFrame("Button", "$parentTab"..id, parent, "ConfigCategoryButtonTemplate")
            f:Hide()
            f:SetID(id)
            tinsert(parent.Tabs, f)
            f:SetText(text)
            local Text = _G[f:GetName().."NormalText"]
            Text:ClearAllPoints()
            Text:SetAllPoints()
            Text:SetJustifyH("CENTER")
        local width = parent:GetWidth() - 20
        f:SetSize(width / 6, Text:GetHeight() + 10)
            f:SetHighlightTexture("Interface\\PaperDollInfoFrame\\UI-Character-Tab-Highlight")
            if id == 1 then
                f:SetPoint("TOPLEFT",parent,"TOPLEFT", 0, 0)
            else
                f:SetPoint("LEFT",parent.Tabs[id-1],"RIGHT", 0, 0)
            end
            f.widgets = CreateFrame("Frame", nil, f)
            f.widgets:Hide()
            f.widgets:SetSize(parent:GetWidth(), parent:GetHeight() - f:GetHeight()) 
            f.widgets:SetPoint("TOPLEFT", parent.Tabs[1], "BOTTOMLEFT")
            f:SetScript("OnClick", TabOnClick)
            f:Show()
            return f
        end
 
    local function UpdateSetting(self)
        local Parent = LockoutConfigFrame
        local RaidFrame = Parent.RaidFrame
        SinLockoutDB.Raids[self.ID] = self:GetChecked()
        RaidInfo[self.ID].FontString:SetShown(self:GetChecked())
        RaidFrame:redrawRaids()
    end
 
    local function CreateCheckBox(parent, instanceid, name, label)
        local f = CreateFrame("CheckButton", "$parent"..instanceid, parent, "ChatConfigCheckButtonTemplate")
        f.Label = f:CreateFontString(nil, "OVERLAY");
        f.Label:SetFontObject("GameTooltipText");
        f.Label:SetPoint("LEFT", f, "RIGHT", 5, 0);
        f.Label:SetText(label)
        f.ID = instanceid
        f:SetScript("OnClick", UpdateSetting)
        f:SetChecked(SinLockoutDB.Raids[instanceid])
        RaidInfo[instanceid].FontString:SetShown(SinLockoutDB.Raids[instanceid])
        return f
    end
    
    local f = LockoutConfigFrame   
    f.Tabs = {}
    local TabSettings = SinLockoutDB.Raids
    local tab = CreateTab(1, f, "Settings")
    
    tab:ClearAllPoints() 
    tab:SetPoint("TOPLEFT", 10, -40)
    
    local sheet = tab.widgets       
    
    sheet.General = sheet:CreateFontString(nil, "OVERLAY");
    sheet.General:SetFontObject("GameFontHighlight");
    sheet.General:SetPoint("TOP", sheet, "TOP", 0, -20);
    sheet.General:SetText("|cfff39c33HUD Settings|r");  
    
    ChkBoxVar:SetParent(sheet)
    ChkBoxVar:SetPoint('TOP', 35, -50)
    
    criToggle:SetParent(sheet)
    criToggle:SetPoint('TOPLEFT', 110, -50)

	minimapOption:SetParent(sheet)
	minimapOption:SetPoint('TOP', criToggle, 'BOTTOM', 0, -5)	
	
	SinReset:SetParent(sheet)
	SinReset:SetPoint('BOTTOMLEFT', 0, 45)	
    
    slider:SetParent(sheet) 
    slider:SetPoint("CENTER",0,10)
    slider.slideTitle:SetPoint("TOP", slider, "BOTTOM", 0, 0);      
    
    tab = CreateTab(2, f, "Raids")
    sheet = tab.widgets 
    
    sheet.raid40 = sheet:CreateFontString(nil, "OVERLAY");
    sheet.raid40:SetFontObject("GameFontHighlight");
    sheet.raid40:SetPoint("TOPLEFT", sheet, "TOPLEFT", 60, -15);
    sheet.raid40:SetText("|cfff39c33Raid [40]|r");    
    local anchored, last

    for i=1, #DisplaySequence do
    	local settings = RaidInfo[DisplaySequence[i]]
    	local instanceID = DisplaySequence[i] 
    	if settings.size == 40 then
    		sheet[instanceID] = CreateCheckBox(sheet, instanceID, instanceID, settings.nameConfig)
    		if not anchored then
    			anchored = true
    			sheet[instanceID]:SetPoint('TOPLEFT', 60, -32)
    		else
    			sheet[instanceID]:SetPoint('TOP', last, 'BOTTOM', 0, -5) 
    		end
    		last = sheet[instanceID]
    	end
    end
    anchored, last = nil, nil
 
    sheet.raids20 = sheet:CreateFontString(nil, "OVERLAY");
    sheet.raids20:SetFontObject("GameFontHighlight");
    sheet.raids20:SetPoint("TOP", sheet, "TOP", 100, -15);
    sheet.raids20:SetText("|cfff39c33Raid [20]|r"); 

    for i=1, #DisplaySequence do
    	local settings = RaidInfo[DisplaySequence[i]]
    	local instanceID = DisplaySequence[i] 
    	if settings.size == 20 then
    		sheet[instanceID] = CreateCheckBox(sheet, instanceID, instanceID, settings.nameConfig)
    		if not anchored then
    			anchored = true
    			sheet[instanceID]:SetPoint('TOP', sheet, 'TOP', 60, -32)
    		else
    			sheet[instanceID]:SetPoint('TOP', last, 'BOTTOM', 0, -5) 
    		end
    		last = sheet[instanceID]
    	end
    end

    TabOnClick(f.Tabs[1])
end
 
local function SetFont(self)
	self:SetFont("Fonts\\ARIALN.ttf", SinLockoutDB.RaidFontSize, "OUTLINE")
end
     
local function CreateRaidStrings(self)
	local function CreateText(parent, instanceid)
	    local f = parent:CreateFontString("$parent"..instanceid, "OVERLAY", "GameFontNormal")
	    f:SetFont("Fonts\\ARIALN.ttf", 8, "OUTLINE")
	    f:SetTextColor(1,1,1,1)
	    RaidInfo[instanceid].FontString = f
	    f.ID = instanceid -- the raid instance id
	    return f
	end
	for i=1, #DisplaySequence do
	    if SinLockoutDB and SinLockoutDB.Raids[DisplaySequence[i]] == nil then
	        print("|cffff0000Classic Raid Info:|r Missing Saved Variable:|cff00ff00", DisplaySequence[i])
	    end
	    CreateText(self, DisplaySequence[i])
	end
end

local SinLockout = CreateFrame("frame", "SinLockoutFrame", UIParent, BackdropTemplateMixin and "BackdropTemplate")
function SinLockout:RestiseStats()
	for k, v in pairs(RaidInfo) do
		SetFont(v.FontString)
	end
end
CreateRaidStrings(SinLockout)
 
SinLockout:RegisterEvent("PLAYER_LOGIN")
SinLockout:RegisterEvent("BOSS_KILL")
SinLockout:RegisterEvent("UPDATE_INSTANCE_INFO")
 
------------------------
-- Customizing the frame
------------------------
SinLockout:SetBackdrop({
    bgFile="Interface\\DialogFrame\\UI-DialogBox-Background",
    tile=1, tileSize=0, edgeSize=0,
})
SinLockout:SetBackdropColor(1,1,1,1)
SinLockout:SetWidth(100)
SinLockout:SetHeight(headerHeight)
SinLockout:SetPoint("CENTER",UIParent)
SinLockout:EnableMouse(false)
SinLockout:SetMovable(true)
SinLockout:SetUserPlaced(true)
SinLockout:SetClampedToScreen(false)
SinLockout:RegisterForDrag("LeftButton")
SinLockout:SetScript("OnDragStart", function(self) self:StartMoving() end)
SinLockout:SetScript("OnDragStop", function(self) self:StopMovingOrSizing() end)
SinLockout:SetFrameStrata("BACKGROUND")
SinLockout.DragText = SinLockout:CreateFontString(nil, "OVERLAY");
SinLockout.DragText:SetFontObject("GameFontHighlightSmall");
SinLockout.DragText:SetTextColor(1, 1, 1)
SinLockout.DragText:SetText("Classic Raid Info")
SinLockout.DragText:SetPoint("CENTER")
SinLockout.DragText:Hide()

local Updatespeed = 60
local NextUpdate = mod(GetServerTime(), 2)
local function OnUpdate(self, elapsed)
	NextUpdate = NextUpdate - elapsed
	if NextUpdate > 0 then return end
	NextUpdate = Updatespeed
	local numInstances = #DisplaySequence
	for i = 1, numInstances do
		local name, instanceid, reset, locked, encounterProgress = GetInstanceTimeInfo(i)
		local status = RaidInfo[instanceid]
		UpdateStatus(status, status.locked, SecondsToTime(reset), status.encounterProgress)
	end
end

function SinLockout:redrawRaids()
	local first, last
	local width = 0
	for i=1, #DisplaySequence do
		local k = DisplaySequence[i] 
		local v = RaidInfo[k]
		if v.FontString:IsShown() then
			v.FontString:ClearAllPoints()
			if not first then
				v.FontString:SetPoint("TOPLEFT", 0, -headerHeight)
				first = true
			else
				if SinLockoutDB.SinDirection then
					v.FontString:SetPoint("LEFT", last, "RIGHT", 7, 0) 
					width = width + 7 + v.FontString:GetWidth()
				elseif not SinLockoutDB.SinDirection then
					v.FontString:SetPoint("TOPLEFT", last, "BOTTOMLEFT")
					if width < v.FontString:GetWidth() then
						width = v.FontString:GetWidth()
					end
				end             
			end
			last = v.FontString
		end
	end
	self:SetWidth(width)
end

SinLockout:SetScript("OnEvent", function (self, event, ...)
	if event == "PLAYER_LOGIN" then
		print("|cff00f26d[CRI]Classic Raid Info v1.13-r6|r loaded. Type |cff00c0ff/cri|r to open the settings.")
		initSinLockoutDB()             
		self:RestiseStats()          
		CreateConfig(self)
		StaticPopupDialogs["SINLOCKOUT_APPLY_SETTINGS"] = {
			text = "Apply changes and reload ?",
			button1 = "Yes",
			button2 = "No",
			timeout = 0,
			whileDead = true,
			hideOnEscape = false,       
			OnAccept = function(self) ReloadUI() end,
			OnCancel = function(self) end, 
		}
 
		StaticPopupDialogs["SINLOCKOUT_HUD_RESET"] = {
			text = "Reset the raid info frame position ?",
			button1 = "Yes",
			button2 = "No",
			timeout = 0,
			whileDead = true,
			hideOnEscape = false,       
			OnAccept = function(self) 
				SinLockoutFrame:SetUserPlaced(false)
				SinLockoutFrame:ClearAllPoints()
				SinLockoutFrame:SetPoint("CENTER", 0, 0)
				SinLockoutFrame:SetUserPlaced(true)
			end,
			OnCancel = function(self) end, 
		}
		UpdateAllInstances()
		self:redrawRaids()
		self:SetScript("OnUpdate", OnUpdate)
		return
	elseif event == "BOSS_KILL" then
		RequestRaidInfo()
		return
	end
	UpdateAllInstances()
end)  

-------------------------------------------
-- Slash command to open the Settings frame
-------------------------------------------
SLASH_CRI1 = "/cri"
function SlashCmdList.CRI()
  if (LockoutConfigFrame:IsVisible()) then
      HideUIPanel(LockoutConfigFrame);
  else
      ShowUIPanel(LockoutConfigFrame);
  end
end